diff --git a/core/modules/views/views.module b/core/modules/views/views.module
index c9f0877..bc7706a 100644
--- a/core/modules/views/views.module
+++ b/core/modules/views/views.module
@@ -837,3 +837,12 @@ function views_view_delete(EntityInterface $entity) {
     }
   }
 }
+
+/**
+ * Implements hook_block_view_alter().
+ */
+function views_block_view_alter(array &$build,  $block) {
+  if ($build['#base_plugin_id'] == 'views_exposed_filter_block') {
+    $build['#attached']['drupalSettings']['views_exposed_form_blocks'][$build['#id']] = $build['#id'];
+  }
+}

diff --git a/core/modules/views/js/ajax_view.js b/core/modules/views/js/ajax_view.js
index 85975b5..4f30b07 100644
--- a/core/modules/views/js/ajax_view.js
+++ b/core/modules/views/js/ajax_view.js
@@ -83,9 +83,21 @@
 
     this.settings = settings;
 
-    // Add the ajax to exposed forms.
-    this.$exposed_form = $('form#views-exposed-form-' + settings.view_name.replace(/_/g, '-') + '-' + settings.view_display_id.replace(/_/g, '-'));
-    this.$exposed_form.once('exposed-form').each($.proxy(this.attachExposedFormAjax, this));
+    // Check if views form is exposed as a block.
+    var exposedFormBlocks = drupalSettings.views_exposed_form_blocks;
+    if (exposedFormBlocks) {
+      for(var prop in exposedFormBlocks){
+        var blockSelector = $('#block-' + exposedFormBlocks[prop].replace(/_/g, '-'));
+        // Add the ajax to exposed forms.
+        this.$exposed_form = $('form#views-exposed-form-' + settings.view_name.replace(/_/g, '-') + '-' + settings.view_display_id.replace(/_/g, '-'), blockSelector);
+        this.$exposed_form.once('exposed-form').each($.proxy(this.attachExposedFormAjax, this));
+      }
+    }
+    else {
+      // Add the ajax to exposed forms.
+      this.$exposed_form = $('form#views-exposed-form-' + settings.view_name.replace(/_/g, '-') + '-' + settings.view_display_id.replace(/_/g, '-'));
+      this.$exposed_form.once('exposed-form').each($.proxy(this.attachExposedFormAjax, this));
+    }
 
     // Add the ajax to pagers.
     this.$view